# SPDX-FileCopyrightText: 2025 Florian Obersteiner <f.obersteiner@kit.edu>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import pandas as pd


def dataframe_to_geojson(
    df,
    lat_col="latitude",
    lon_col="longitude",
    alt_col="altitude",
    time_interval_seconds=10,
):
    """
    Converts a pandas DataFrame with latitude, longitude, and altitude columns
    to a GeoJSON LineString FeatureCollection.

    Args:
        df (pd.DataFrame): The DataFrame containing the flight track data.
        lat_col (str): The name of the latitude column.
        lon_col (str): The name of the longitude column.
        alt_col (str): The name of the altitude column.
        time_interval_seconds (int): the time interval between each point in seconds.

    Returns:
        str: A GeoJSON string representing the flight track.
    """

    if not all(col in df.columns for col in [lat_col, lon_col, alt_col]):
        raise ValueError(f"DataFrame must contain columns: {lat_col}, {lon_col}, {alt_col}")

    coordinates = []
    for _, row in df.iterrows():
        coordinates.append(list(map(float, [row[lon_col], row[lat_col], row[alt_col]])))

    return {
        "type": "FeatureCollection",
        "features": [
            {
                "type": "Feature",
                "properties": {
                    # "time_interval_seconds": time_interval_seconds
                    "origin": "CPT",
                    "destination": "MUC",
                    "stroke": "#00ff80",
                    "stroke-width": 3,
                },
                "geometry": {"type": "LineString", "coordinates": coordinates},
            }
        ],
    }


if __name__ == "__main__":
    # Example usage:
    # Create a sample DataFrame
    data = {
        "latitude": [34.0522, 34.0600, 34.0700],
        "longitude": [-118.2437, -118.2500, -118.2600],
        "altitude": [1000, 1100, 1200],
    }
    df = pd.DataFrame(data)

    # Convert to GeoJSON
    geojson_string = dataframe_to_geojson(df)
    print(geojson_string)

    # Example usage with time
    data_time = {
        "latitude": [34.0522, 34.0600, 34.0700, 34.0800],
        "longitude": [-118.2437, -118.2500, -118.2600, -118.2700],
        "altitude": [1000, 1100, 1200, 1300],
    }
    df_time = pd.DataFrame(data_time)
    geojson_string_time = dataframe_to_geojson(df_time, time_interval_seconds=10)
    print(geojson_string_time)
