# SPDX-FileCopyrightText: 2025 Florian Obersteiner <f.obersteiner@kit.edu>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import dash
import pandas as pd
from dash import dcc, html

from .config import DotDict


def create_layout(df: pd.DataFrame, config: DotDict) -> list:
    """
    Create the layout for the dashboard.

    Makes a list of html / Dash components.
    """
    flights = df[["flight_number", "date"]].drop_duplicates("flight_number")

    flight_opts = [
        {
            "label": f"{row.flight_number:d} | {row.date}",
            "value": row.flight_number,
        }
        for row in flights.itertuples()
    ]

    var_opts = [
        {
            "label": c,
            "value": c,
        }
        # exclude processing variables:
        for c in df.columns
        if c not in ["flight_number", "date", "BB_flag"]
    ]
    var_sel_idx = 0
    for idx, vo in enumerate(var_opts):
        if vo["label"] == "ACN":
            var_sel_idx = idx

    return [
        html.Header(
            [
                # Title on the left
                html.Div(config.TITLE + config.HEADERSUFFIX, className="title-text"),
                # Logos on the right
                html.Div(
                    [
                        # First logo
                        html.Div(
                            [
                                html.A(
                                    html.Img(
                                        src=dash.get_asset_url("iagos_logo.png"),
                                        className="header-logo",
                                    ),
                                    href=config.IAGOS_URL,
                                    target="_blank",
                                )
                            ],
                            className="logo-wrapper",
                        ),
                        # Second logo
                        html.Div(
                            [
                                html.A(
                                    html.Img(
                                        src=dash.get_asset_url("iriscc_logo.svg"),
                                        className="header-logo",
                                    ),
                                    href=config.IRISCC_URL,
                                    target="_blank",
                                )
                            ],
                            className="logo-wrapper",
                        ),
                    ],
                    className="logo-container",
                ),
            ],
            className="title-bar",
        ),
        #
        # --- vvv --- main content
        html.Div(
            [
                html.Div(
                    id="flight-select",
                    children=[
                        html.Label(
                            "Flight:",
                            style={"font-weight": "bold", "margin-right": "29px"},
                        ),
                        dcc.Dropdown(
                            id="flight-dropdown",
                            options=flight_opts,  # type: ignore
                            value=flight_opts[-1]["value"],  # type: ignore
                            clearable=False,
                            searchable=True,
                            style={
                                "display": "inline-block",
                                "width": "190px",
                            },
                        ),
                        html.Label(
                            "",
                            id="flight-dep-dest",
                            style={"margin-left": "29px", "font-size": "12px"},
                        ),
                    ],
                    style={
                        "display": "flex",
                        "flex-direction": "row",
                        "justify-content": "left",
                        "align-items": "center",
                    },
                ),
                html.Div(
                    id="variable-select",
                    children=[
                        html.Label(
                            "Variable:",
                            style={"font-weight": "bold", "margin-right": "10px"},
                        ),
                        dcc.Dropdown(
                            id="variable-dropdown",
                            options=var_opts,  # type: ignore
                            value=var_opts[var_sel_idx]["value"],  # type: ignore
                            clearable=False,
                            searchable=True,
                            style={
                                "display": "inline-block",
                                "width": "190px",
                            },
                        ),
                        html.Label(
                            "",
                            id="var-info",
                            style={"margin-left": "29px", "font-size": "12px"},
                        ),
                    ],
                    style={
                        "display": "flex",
                        "flex-direction": "row",
                        "justify-content": "left",
                        "align-items": "center",
                    },
                ),
                dcc.Graph(
                    id="fig-map",
                    style={
                        "margin-top": "10px",
                        "margin-right": "10px",
                        "margin-bottom": "0px",
                        "margin-left": "10px",
                    },
                ),
                dcc.Graph(
                    id="fig-ts",
                    style={
                        "margin-top": "10px",
                        "margin-right": "10px",
                        "margin-bottom": "0px",
                        "margin-left": "10px",
                    },
                ),
            ]
        ),
        # --- ^^^ ---  main content
        #
        html.Footer(
            [
                html.Span(
                    [
                        "© 2025 ",
                        html.A(
                            "KIT",
                            href="https://www.kit.edu",
                            target="_blank",
                            style={"textDecoration": "underline", "color": "inherit"},
                        ),
                        " / IMKASF, under EU grant agreement 101131261",
                    ],
                    style={"float": "left"},
                ),
                html.Div(
                    [
                        html.A(
                            [
                                html.I(
                                    className="fa-solid fa-folder-open",
                                    style={"marginRight": "5px"},
                                ),
                                "data",
                            ],
                            href=config.DATAURL,
                            target="_blank",
                            style={"color": "white"},
                        ),
                        html.A(
                            [
                                html.I(className="fab fa-gitlab", style={"marginRight": "5px"}),
                                f"src ({config.VERSION})",
                            ],
                            href=config.CODEURL,
                            target="_blank",
                            style={"color": "white", "padding-left": "15px"},
                        ),
                    ]
                ),
            ],
            className="footer",
        ),
    ]
